@@ -6,27 +6,27 @@
 #include <mutex>
 #include <string>
 
-#include "AL/alc.h"
-
 #include "albyte.h"
 #include "alcmain.h"
-#include "alexcpt.h"
+#include "core/except.h"
 
 
+using uint = unsigned int;
+
 struct ClockLatency {
     std::chrono::nanoseconds ClockTime;
     std::chrono::nanoseconds Latency;
 };
 
 struct BackendBase {
-    virtual void open(const ALCchar *name) = 0;
+    virtual void open(const char *name) = 0;
 
     virtual bool reset();
     virtual void start() = 0;
     virtual void stop() = 0;
 
-    virtual ALCenum captureSamples(al::byte *buffer, ALCuint samples);
-    virtual ALCuint availableSamples();
+    virtual void captureSamples(al::byte *buffer, uint samples);
+    virtual uint availableSamples();
 
     virtual ClockLatency getClockLatency();
 
@@ -43,7 +43,7 @@ protected:
 
 #ifdef _WIN32
     /** Sets the channel order given the WaveFormatEx mask. */
-    void setChannelOrderFromWFXMask(ALuint chanmask);
+    void setChannelOrderFromWFXMask(uint chanmask);
 #endif
 };
 using BackendPtr = std::unique_ptr<BackendBase>;
@@ -93,16 +93,25 @@ protected:
 
 namespace al {
 
+enum class backend_error {
+    NoDevice,
+    DeviceError,
+    OutOfMemory
+};
+
 class backend_exception final : public base_exception {
+    backend_error mErrorCode;
+
 public:
     [[gnu::format(printf, 3, 4)]]
-    backend_exception(ALCenum code, const char *msg, ...) : base_exception{code}
+    backend_exception(backend_error code, const char *msg, ...) : mErrorCode{code}
     {
         std::va_list args;
         va_start(args, msg);
         setMessage(msg, args);
         va_end(args);
     }
+    backend_error errorCode() const noexcept { return mErrorCode; }
 };
 
 } // namespace al
